@@ -5,21 +5,11 @@ from einops import rearrange, repeat
 
 # classes
 
-class ScaleNorm(nn.Module):
-    def __init__(self, dim, eps = 1e-5):
-        super().__init__()
-        self.eps = eps
-        self.g = nn.Parameter(torch.ones(1))
-
-    def forward(self, x):
-        n = torch.norm(x, dim = -1, keepdim = True).clamp(min = self.eps)
-        return x / n * self.g
-
 class PreNorm(nn.Module):
     def __init__(self, dim, fn):
         super().__init__()
         self.fn = fn
-        self.norm = ScaleNorm(dim)
+        self.norm = nn.LayerNorm(dim)
 
     def forward(self, x, *args, **kwargs):
         x = self.norm(x)
@@ -149,7 +139,7 @@ class TimeSformer(nn.Module):
             ]))
 
         self.to_out = nn.Sequential(
-            ScaleNorm(dim),
+            nn.LayerNorm(dim),
             nn.Linear(dim, num_classes)
         )
 
